--[[---------------------------------------------------------------------------

Copyright (c) 2008-2017 by K. Scott Piel 
All Rights Reserved

E-mail: < kscottpiel@gmail.com >

This file is part of nUI.

The author no longer develops or directly supports this addon and has released it
into the public domain under the Creative Commons Attribution-NonCommercial 3.0 
Unported license - a copy of which is included in this distribution. This source
may not be distributed without said license.
	   
nUI is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; 
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the enclosed license for more details.
	
THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS  "AS IS" AND 
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT  LIMITED TO, THE IMPLIED 
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED 
OF THE POSSIBILITY OF SUCH DAMAGE.

--]]---------------------------------------------------------------------------


-- Create nUI's replaced frames table if it doesn't exist
nUI_ReplacedFrames = nUI_ReplacedFrames or {}

-- Identify the replaced frame by using the name of the Blizzard frame
-- This is in case nUI needs to do some work without knowing what the name of the replacement addon is
-- Only the last 
-- if no custom ones are loaded then Blizzard's one will be used instead

-- Handle custom trackers that have become incompatible 
nUI_CompatibleCustomTrackerActive = true

------------------------------------------
-- Default: Blizzard Tracker
------------------------------------------

nUI_BlizzardTrackerActive = true
nUI_Options.BlizzardTrackerAnchorLeft = true
nUI_Options.BlizzardTrackerAnchorRight = false 

-- set up a slash command handler for dealing with setting the display of cooldowns on the action bars		
local master = nUI_SlashCommands[nUI_SLASHCMD_OBJECTIVES];
local option = master.sub_menu[nUI_SLASHCMD_OBJECTIVES_LEFT];

nUI_SlashCommands:setSubHandler( master.command, option.command,

    function( msg )

        nUI_Options.BlizzardTrackerAnchorLeft = true;
        nUI_Options.BlizzardTrackerAnchorRight = false 

        nUI_ResetWatchFrame()

        DEFAULT_CHAT_FRAME:AddMessage( (option.message):format( nUI_Options.BlizzardTrackerAnchorLeft and nUI_L["|cFF00FF00ENABLED|r"] or nUI_L["|cFFFF0000DISABLED|r"] ), 1, 0.83, 0 );

    end
);

-- set up a slash command handler for dealing with setting the display of cooldowns on the action bars		
local master = nUI_SlashCommands[nUI_SLASHCMD_OBJECTIVES];
local option = master.sub_menu[nUI_SLASHCMD_OBJECTIVES_RIGHT];

nUI_SlashCommands:setSubHandler( master.command, option.command,

    function( msg )

        nUI_Options.BlizzardTrackerAnchorLeft = false;
        nUI_Options.BlizzardTrackerAnchorRight = true 

        nUI_ResetWatchFrame()

        DEFAULT_CHAT_FRAME:AddMessage( (option.message):format( nUI_Options.BlizzardTrackerAnchorRight and nUI_L["|cFF00FF00ENABLED|r"] or nUI_L["|cFFFF0000DISABLED|r"] ), 1, 0.83, 0 );

    end
);



------------------------------------------
-- !Kaliel's Tracker
------------------------------------------
local function ActivateKalielsTracker()
    nUI_ReplacedFrames["ObjectiveTracker"] = {
        frame = _G["!KalielsTrackerFrame"],
        frameName = "!KalielsTrackerFrame",
        labelText = "Kaliels Tracker Frame",
        parent = "UIParent",
        addOn = "!KalielsTracker",
        exclusionFrames = nil,
        requiredFrames = nil,
        defaultPosition = 
        {
            anchorPt = "CENTER",
            relativeTo = "UIParent",
            relativePt = "CENTER",
            xOfs = 0,
            yOfs = 0,
        },

        -- Function to update any connected children - currently not working as expected
        -- If the addon itself automatically connects the children based on placement of parent
        -- then a reload will most likely fix the problem.
        UpdateChildren = function(parentFrame)
            parentFrame.Buttons:SetMovable( true );
            parentFrame.Buttons:StartMoving();
            parentFrame.Buttons:ClearAllPoints();
            parentFrame.Buttons:SetPoint("TOPRIGHT", parentFrame, "TOPLEFT",2, 0);
            parentFrame.Buttons:StopMovingOrSizing();
        end
    }
end
------------------------------------------


-------------------------------------------------------------------------------------
-- Events
local nUILoaded = false
local kalielsLoaded = false
local kalielsCompatible = false   -- currently incompatible for a nUI mover frame

local function onEvent( self, event, arg1 )
    if event == "ADDON_LOADED" then
        if arg1 == "nUI" then nUILoaded = true end
        if arg1 == "!KalielsTracker" then kalielsLoaded = true end
        if nUILoaded then
            kalielsLoaded = IsAddOnLoaded("!KalielsTracker") 
            if kalielsLoaded then 
                if kalielsCompatible then
                    ActivateKalielsTracker()
                    nUI_BlizzardTrackerActive = false
                else
                    nUI_CompatibleCustomTrackerActive = false
                    nUI_BlizzardTrackerActive = false
                end
            end
        end            
    end
end


-------------------------------------------------------------------------------------
-- Events Frame

local frame = CreateFrame( "Frame", "nUI_ObjectiveTrackerEvents", WorldFrame )
frame:SetScript( "OnEvent", onEvent );
frame:RegisterEvent( "ADDON_LOADED" );
